@@ -7,8 +7,8 @@ from steinbock.classification._cli import classify_cmd_group
 from steinbock.segmentation._cli import segment_cmd_group
 from steinbock.measurement._cli import measure_cmd_group
 from steinbock.export._cli import export_cmd_group
-from steinbock.tools._cli import tools_cmd_group
-from steinbock.version import version as steinbock_version
+from steinbock.utils._cli import utils_cmd_group
+from steinbock._version import version as steinbock_version
 
 
 @click.group(name="steinbock", cls=OrderedClickGroup)
@@ -22,5 +22,5 @@ steinbock_cmd_group.add_command(classify_cmd_group)
 steinbock_cmd_group.add_command(segment_cmd_group)
 steinbock_cmd_group.add_command(measure_cmd_group)
 steinbock_cmd_group.add_command(export_cmd_group)
-steinbock_cmd_group.add_command(tools_cmd_group)
+steinbock_cmd_group.add_command(utils_cmd_group)
 steinbock_cmd_group.add_command(apps_cmd_group)
